==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceQuotaSpecBuilder extends io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluentImpl<io.fabric8.kubernetes.api.model.ResourceQuotaSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ResourceQuotaSpec,io.fabric8.kubernetes.api.model.ResourceQuotaSpecBuilder>{
  public ResourceQuotaSpecBuilder() {
    this(false);
  }
  public ResourceQuotaSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceQuotaSpec(), validationEnabled);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceQuotaSpec(), validationEnabled);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance) {
    this(fluent, instance, false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHard(instance.getHard()); 
    fluent.withScopeSelector(instance.getScopeSelector()); 
    fluent.withScopes(instance.getScopes()); 
    this.validationEnabled = validationEnabled; 
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance) {
    this(instance,false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHard(instance.getHard()); 
    this.withScopeSelector(instance.getScopeSelector()); 
    this.withScopes(instance.getScopes()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ResourceQuotaSpec build() {
    ResourceQuotaSpec buildable = new ResourceQuotaSpec(fluent.getHard(),fluent.getScopeSelector(),fluent.getScopes());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceQuotaSpecBuilder that = (ResourceQuotaSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceQuotaSpecBuilder extends io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluentImpl<io.fabric8.kubernetes.api.model.ResourceQuotaSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ResourceQuotaSpec,io.fabric8.kubernetes.api.model.ResourceQuotaSpecBuilder>{
  public ResourceQuotaSpecBuilder() {
    this(false);
  }
  public ResourceQuotaSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceQuotaSpec(), validationEnabled);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceQuotaSpec(), validationEnabled);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance) {
    this(fluent, instance, false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHard(instance.getHard()); 
    fluent.withScopeSelector(instance.getScopeSelector()); 
    fluent.withScopes(instance.getScopes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance) {
    this(instance,false);
  }
  public ResourceQuotaSpecBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHard(instance.getHard()); 
    this.withScopeSelector(instance.getScopeSelector()); 
    this.withScopes(instance.getScopes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ResourceQuotaSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ResourceQuotaSpec build() {
    ResourceQuotaSpec buildable = new ResourceQuotaSpec(fluent.getHard(),fluent.getScopeSelector(),fluent.getScopes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceQuotaSpecBuilder that = (ResourceQuotaSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
